@@ -247,7 +247,7 @@ sub reparent {
     $self->{sensitivity_current} = 0;
 
     # $self->{data}= $dataref;
-    $self->{log}->debug( "w2disable ", Dumper( @{ $self->{w2disable} } ) );
+    $self->{log}->debug( "w2disable ", sub {Dumper( @{ $self->{w2disable} })} );
     $self->{top_widget} = $ctrl;
 
 }
