@@ -12,6 +12,9 @@ use DataAccess::Dbc::Service;
 use Log::Log4perl qw(:easy);
 Log::Log4perl->easy_init($DEBUG);
 
+use Log::Any::Adapter;
+Log::Any::Adapter->set('Log::Log4perl');
+
 use Forms::Langues2;
 
 =for comment
