@@ -5,6 +5,10 @@ use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use Gtk2 -init;
 use Log::Log4perl qw(:easy);
 Log::Log4perl->easy_init($DEBUG);
+
+use Log::Any::Adapter;
+Log::Any::Adapter->set('Log::Log4perl');
+
 use Forms::Langues2;
 use DataAccess::Sqla::Service;
 use DBI;
